==> haskell-tagsoup-0.14.8-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tagsoup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagsoup
version: 0.14.8
id: tagsoup-0.14.8-bQuTxVSfm0MHTKaVRPw4
key: tagsoup-0.14.8-bQuTxVSfm0MHTKaVRPw4
license: BSD-3-Clause
copyright: Neil Mitchell 2006-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/tagsoup#readme
synopsis: Parsing and extracting information from (possibly malformed) HTML/XML documents
description:
    TagSoup is a library for parsing HTML/XML. It supports the HTML 5 specification,
    and can be used to parse either well-formed XML, or unstructured and malformed HTML
    from the web. The library also provides useful functions to extract information
    from an HTML document, making it ideal for screen-scraping.
    .
    Users should start from the "Text.HTML.TagSoup" module.
category: XML
abi: dc04dcf8fd5f12182547b85976ff7aaf
exposed: True
exposed-modules:
    Text.HTML.TagSoup Text.HTML.TagSoup.Entity Text.HTML.TagSoup.Match
    Text.HTML.TagSoup.Tree Text.StringLike
hidden-modules: Text.HTML.TagSoup.Generated
                Text.HTML.TagSoup.Implementation Text.HTML.TagSoup.Manual
                Text.HTML.TagSoup.Options Text.HTML.TagSoup.Parser
                Text.HTML.TagSoup.Render Text.HTML.TagSoup.Specification
                Text.HTML.TagSoup.Type
import-dirs: /usr/lib/ghc-8.6.5/site-local/tagsoup-0.14.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/tagsoup-0.14.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tagsoup-0.14.8
hs-libraries: HStagsoup-0.14.8-bQuTxVSfm0MHTKaVRPw4
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-tagsoup/html/tagsoup.haddock
haddock-html: /usr/share/doc/haskell-tagsoup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagsoup-0.14.8-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tagsoup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagsoup
version: 0.14.8
id: tagsoup-0.14.8-DGG11JtHSmWKGlohPlXRaq
key: tagsoup-0.14.8-DGG11JtHSmWKGlohPlXRaq
license: BSD-3-Clause
copyright: Neil Mitchell 2006-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/tagsoup#readme
synopsis: Parsing and extracting information from (possibly malformed) HTML/XML documents
description:
    TagSoup is a library for parsing HTML/XML. It supports the HTML 5 specification,
    and can be used to parse either well-formed XML, or unstructured and malformed HTML
    from the web. The library also provides useful functions to extract information
    from an HTML document, making it ideal for screen-scraping.
    .
    Users should start from the "Text.HTML.TagSoup" module.
category: XML
abi: 692554a2049cf8f4dea5cf1a8a7aa7bb
exposed: True
exposed-modules:
    Text.HTML.TagSoup Text.HTML.TagSoup.Entity Text.HTML.TagSoup.Match
    Text.HTML.TagSoup.Tree Text.StringLike
hidden-modules: Text.HTML.TagSoup.Generated
                Text.HTML.TagSoup.Implementation Text.HTML.TagSoup.Manual
                Text.HTML.TagSoup.Options Text.HTML.TagSoup.Parser
                Text.HTML.TagSoup.Render Text.HTML.TagSoup.Specification
                Text.HTML.TagSoup.Type
import-dirs: /usr/lib/ghc-8.6.5/site-local/tagsoup-0.14.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/tagsoup-0.14.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tagsoup-0.14.8
hs-libraries: HStagsoup-0.14.8-DGG11JtHSmWKGlohPlXRaq
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-tagsoup/html/tagsoup.haddock
haddock-html: /usr/share/doc/haskell-tagsoup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
